pub enum CommandLexError<'a> {
UnclosedQuote(usize, &'a str),
NamedProhibitsWhitespace(usize, &'a str),
NamedCannotContainNamed(usize, &'a str),
}Expand description
An error that can appear while lexing a command.
Variants
UnclosedQuote(usize, &'a str)
There is a unclosed quote.
NamedProhibitsWhitespace(usize, &'a str)
There is a whitespace before/after equal sign.
NamedCannotContainNamed(usize, &'a str)
There is a nam assignment syntax after equal sign