TransformHint

Enum TransformHint 

pub enum TransformHint {
    Select(HashMap<&'static str, TransformHint>),
    Execute(Vec<TransformHintPart>),
    SelectOrExecute(HashMap<&'static str, TransformHint>, Vec<TransformHintPart>),
}
The hint for TokenTransformer to produce CommandFragment well.

Variants



Select(HashMap<&'static str, TransformHint>)

It should select a command specified in a map.



Execute(Vec<TransformHintPart>)

It should execute command with arguments format hint specified.



SelectOrExecute(HashMap<&'static str, TransformHint>, Vec<TransformHintPart>)

It should select a command specified in a map or execute the command with arguments format hint specified.